/*
 * Java
 *
 * Copyright 2018-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.profiling.internal.snapshot;

import com.microej.profiling.Group;
import com.microej.profiling.profiler.ComparableProfiler;
import com.microej.profiling.profiler.Profiler;

/**
 *
 * A {@link Snapshot} of a {@link Profiler}.
 *
 */
public class Snapshot {
	/**
	 * The type of snapshot.
	 */
	public enum Type {
		/**
		 * The starts of a monitoring.
		 */
		ENTER,
		/**
		 * An intermediate value.
		 */
		LAP,
		/**
		 * The end of a value.
		 */
		EXIT
	}

	private final int level;
	private final String tag;
	private final long sample;
	private final Type type;
	private final Group group;
	private final ComparableProfiler profiler;

	/**
	 * Instantiates a {@link Snapshot}.
	 *
	 * @param level
	 *            the stack's level.
	 * @param tag
	 *            the tag to display.
	 * @param type
	 *            the type of snapshot.
	 * @param group
	 *            the {@link Group}.
	 * @param profiler
	 *            the profiler.
	 */
	public Snapshot(int level, String tag, Type type, Group group, ComparableProfiler profiler) {
		this.level = level;
		this.tag = tag;
		this.type = type;
		this.sample = profiler.getCurrentValue();
		this.group = group;
		this.profiler = profiler;
	}

	/**
	 * Gets the profiler.
	 *
	 * @return the profiler.
	 */
	public ComparableProfiler getProfiler() {
		return this.profiler;
	}

	/**
	 * Gets the stacks level.
	 *
	 * @return the level.
	 */
	public int getLevel() {
		return this.level;
	}

	/**
	 * Gets the tag.
	 *
	 * @return the tag.
	 */
	public String getTag() {
		return this.tag;
	}

	/**
	 * Gets the sample's value.
	 *
	 * @return the sample's value.
	 */
	public long getSample() {
		return this.sample;
	}

	/**
	 * Gets the type of snapshot.
	 *
	 * @return the type.
	 */
	public Type getType() {
		return this.type;
	}

	/**
	 * Gets the group.
	 *
	 * @return the group.
	 */
	public Group getGroup() {
		return this.group;
	}
}
