/*
 * Java
 *
 * Copyright 2018-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.profiling.profiler;

import com.microej.profiling.internal.Strings;

import ej.bon.Util;

/**
 * Profile the time.
 */
public class TimeProfiler implements ComparableProfiler {

	private static final int MS_IN_S = 1_000_000;
	private static final int NS_IN_S = 1_000_000_000;

	/**
	 * The time base.
	 */
	public enum TimeBase {
		/**
		 * Nanosecond.
		 */
		NS,
		/**
		 * Millisecond.
		 */
		MS,
		/**
		 * Second.
		 */
		S
	}

	private static final String PREFIX = Strings.TIME;
	private static final String MS = Strings.MS;
	private static final String NS = Strings.NS;
	private static final String S = Strings.S;
	private static TimeBase base = TimeBase.MS;

	/**
	 * Gets the {@link TimeBase} for the {@link #printValue(long)}.
	 *
	 * @return the base.
	 */
	public static TimeBase getBase() {
		return base;
	}

	/**
	 *
	 * Sets the {@link TimeBase} for the {@link #printValue(long)}.
	 *
	 * @param base
	 *            the base to set.
	 */
	public static void setBase(TimeBase base) {
		TimeProfiler.base = base;
	}

	@Override
	public long getCurrentValue() {
		return Util.platformTimeNanos();
	}

	@Override
	public String printValue(long value) {
		return getValue(value) + getTime();
	}

	@Override
	public String getName() {
		return PREFIX;
	}

	@Override
	public long compare(long start, long end) {
		return end - start;
	}

	private static String getTime() {
		switch (base) {
		case S:
			return S;
		case MS:
			return MS;
		case NS:
		default:
			return NS;
		}
	}

	private static long getValue(long value) {
		switch (base) {
		case S:
			return value / NS_IN_S;
		case MS:
			return value / MS_IN_S;
		case NS:
		default:
			return value;
		}
	}

	@Override
	public boolean isBiggerPrinted(long v1, long v2) {
		return v1 > v2;
	}
}
