/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.basedriver;

import java.io.IOException;

/**
 * Describe the capabilities of a power meter.
 */
public interface PowerMeter extends Profile {

	/**
	 * Default value returned when the power consumption is unknown.
	 */
	int UNKNOWN_VALUE = -1;

	/**
	 * Get the instant power consumption in Watts (positive integer).
	 * 
	 * @return the instant power consumption in Watts, or {@link #UNKNOWN_VALUE} if unknown.
	 */
	int getInstantConsumption();

	/**
	 * Ask for instant consumption to be updated.
	 * 
	 * @throws IOException
	 *             if there is a communication error with the device
	 */
	void requestInstantConsumptionUpdate() throws IOException;

	/**
	 * Get the accumulated power consumption in Watts / hour (positive integer).
	 * 
	 * @return the instant power consumption in Watts / hour, or
	 *         {@link #UNKNOWN_VALUE} if unknown.
	 */
	int getAccumulatedConsumption();

	/**
	 * Ask for accumulated consumption to be updated.
	 * 
	 * @throws IOException
	 *             if there is a communication error with the device
	 */
	void requestAccumulatedConsumptionUpdate() throws IOException;

	/**
	 * Reset the accumulated power consumption to zero.
	 */
	void resetAccumulatedConsumption();

}
