/*
 * Java
 *
 * Copyright 2014-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.basedriver.zwave.device;

import ej.basedriver.BinaryState;
import ej.basedriver.DryContact;
import ej.basedriver.zwave.ZwaveNode;

public class ZwaveDryContact extends ZwaveDevice implements DryContact{
	private int state;

	public ZwaveDryContact(ZwaveNode node) {
		super(node);
		state = BinaryState.UNKNOWN;
	}

	/**
	 * Update the last known state of the switch. This method is supposed to be called only when receiving a status packet.
	 * 
	 * @param newBinaryState
	 *            the new state of the switch
	 */
	public void setState(int newBinaryState) {
		if (state != newBinaryState) {
			this.state = newBinaryState;
			try {
				node.getController().getListener().onEvent(DryContact.class, this);
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
	}

	@Override
	public int getLastKnownState() {
		return state;
	}
}
