/*
 * Java
 *
 * Copyright 2014-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.basedriver.zwave.frame;

import java.io.IOException;

import ej.basedriver.zwave.Session;
import ej.basedriver.zwave.ZwaveController;
import ej.basedriver.zwave.ZwaveProtocol;

public class MemoryGetID extends RequestFrame {

	/**
	 * @param listener the listener.
	 */
	public MemoryGetID(RequestFrameListener listener) {
		super(listener, ZwaveProtocol.FUNC_ID_MEMORY_GET_ID);
	}

	@Override
	public synchronized void handleResponse(ZwaveController controller,
			DataFrame dataFrame) throws IOException {
		super.handleResponse(controller, dataFrame);
		byte [] bytes = dataFrame.getBytes();
		int homeID = (bytes[4] & 0xFF) << 24 | (bytes[5] & 0xFF) << 16 | (bytes[6] & 0xFF) << 8 | (bytes[7] & 0xFF);
		controller.setHomeId(homeID);
		controller.setId(bytes[8]);
		controller.registerController();
	}

	@Override
	public Session getSession() {
		return Session.RESPONSE;
	}
}
