/*
 * Java
 *
 * Copyright 2014-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.basedriver.zwave.frame;

import java.io.IOException;

import ej.basedriver.Node;
import ej.basedriver.zwave.Session;
import ej.basedriver.zwave.ZwaveController;
import ej.basedriver.zwave.ZwaveNode;
import ej.basedriver.zwave.ZwaveProtocol;

public class NodeProtocolInfo extends RequestFrame {
	private final ZwaveNode node;
	/**
	 * @param node
	 */
	public NodeProtocolInfo(RequestFrameListener listener, ZwaveNode node) {
		super(listener, ZwaveProtocol.FUNC_ID_ZW_GET_NODE_PROTOCOL_INFO, 1);
		addParameter(node.getNodeUid());
		this.node = node;
	}

	@Override
	public Session getSession() {
		return Session.RESPONSE;
	}

	@Override
	public void handleResponse(ZwaveController controller, DataFrame frame) throws IOException {
		super.handleResponse(controller, frame);
		byte [] bytes = frame.getBytes();
		node.options(bytes[CAPABILITY_INDEX], bytes[SECURITY_INDEX]);
		node.createProfiles(bytes[BASIC_TYPE_INDEX], bytes[GENERIC_TYPE_INDEX], bytes[SPECIFIC_TYPE_INDEX]);
		try {
			controller.getListener().onRegister(Node.class, node);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}


	private static final int CAPABILITY_INDEX      = 4;
	private static final int SECURITY_INDEX        = 5;
	private static final int BASIC_TYPE_INDEX      = 7;
	private static final int GENERIC_TYPE_INDEX    = 8;
	private static final int SPECIFIC_TYPE_INDEX   = 9;
}
