/*
 * Java
 *
 * Copyright 2015-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.components.dependencyinjection;

import ej.annotation.Nullable;
import ej.components.registry.BundleRegistry;

/**
 * Service loader that retrieve services implementations singleton from the default registry.
 */
public class RegistryServiceLoader implements ServiceLoader {

	private final DefaultServiceLoader defaultServiceLoader;

	/**
	 * Instantiates a new registry service loader.
	 */
	public RegistryServiceLoader() {
		this.defaultServiceLoader = new DefaultServiceLoader();
	}

	@Override
	@Nullable
	public <T> T getService(Class<T> service) {
		return getService(service, true);
	}

	@Override
	public <T> T getService(Class<T> service, Class<? extends T> defaultImplementation) {
		return getService(service, defaultImplementation, true);
	}

	@Override
	@Nullable
	public <T> T getService(Class<T> service, boolean singleton) {
		// break possible recursion by testing that the retrieved service is not the bundle registry
		if (service != BundleRegistry.class && singleton) {
			BundleRegistry registry = ServiceLoaderFactory.getServiceLoader().getService(BundleRegistry.class);
			if (registry != null) {
				try {
					T serviceInstance = registry.getService(service);
					if (serviceInstance != null) {
						return serviceInstance;
					}
				} catch (IllegalStateException e) {
					// the registry is not is the right state
				}
			}
		}
		return this.defaultServiceLoader.getService(service, singleton);
	}

	@Override
	public <T> T getService(Class<T> service, Class<? extends T> defaultImplementation, boolean singleton) {
		// break possible recursion by testing that the retrieved service is not the bundle registry
		if (service != BundleRegistry.class && singleton) {
			BundleRegistry registry = ServiceLoaderFactory.getServiceLoader().getService(BundleRegistry.class);
			if (registry != null) {
				try {
					T serviceInstance = registry.getService(service);
					if (serviceInstance != null) {
						return serviceInstance;
					}
				} catch (IllegalStateException e) {
					// the registry is not is the right state
					throw new IllegalStateException();
				}
			}
		}
		return this.defaultServiceLoader.getService(service, defaultImplementation, singleton);
	}

}
