/*
 * Java
 *
 * Copyright 2016-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.data.cbor;

import java.io.OutputStream;

import ej.cbor.CborEncoder;
import ej.data.AbstractDataWriter;
import ej.data.DataWriter;

/**
 * Implementation of a {@link DataWriter} for a CBOR stream.
 */
public class DataWriterCBOR extends AbstractDataWriter {

	CborEncoder encoder;

	/**
	 * Creates a new {@link DataWriter} on the given {@link OutputStream}.
	 * The {@link OutputStream} is automatically flushed when the data has been fully written.
	 * @param os the {@link OutputStream} to which the CBOR structured data is written.
	 */
	public DataWriterCBOR(OutputStream os){
		super(os);
		encoder = new CborEncoder(os);
	}

	@Override
	public void writeBooleanValue0(boolean value) throws Throwable{
		encoder.writeBoolean(value);
	}

	@Override
	public void writeIntValue0(int value) throws Throwable{
		encoder.writeInt(value & 0xFFFFFFFFl);
	}

	@Override
	public void writeLongValue0(long value) throws Throwable{
		encoder.writeInt(value);
	}

	@Override
	public void writeStringValue0(String value) throws Throwable{
		encoder.writeTextString(value);
	}

	@Override
	public void writeDoubleValue0(double value) throws Throwable{
		encoder.writeDouble(value);
	}

	@Override
	public void writeArrayValueStart0() throws Throwable{
		encoder.writeArrayStart();
	}

	@Override
	public void writeArrayValueEnd0() throws Throwable{
		encoder.writeBreak();
	}

	@Override
	public void writeMapValueStart0() throws Throwable{
		encoder.writeMapStart();
	}

	@Override
	public void writeMapValueEnd0() throws Throwable{
		encoder.writeBreak();
	}

	@Override
	protected void writeIntKey0(int value) throws Throwable {
		encoder.writeInt(value);
	}

	@Override
	protected void writeStringKey0(String value) throws Throwable {
		encoder.writeTextString(value);
	}

}
