/*
 * Java
 *
 * Copyright 2017-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.data.pubsub.paho;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStream;

import org.eclipse.paho.client.mqttv3.IMqttAsyncClient;
import org.eclipse.paho.client.mqttv3.MqttException;

/**
 * {@link OutputStream} for MQTT packet with a flush method that
 * sends the packet.
 */
public class MqttPacketOutputStream extends ByteArrayOutputStream{

	/** The MQTT Topic */
	private final String topic;
	/** The MQTT Client */
	private final IMqttAsyncClient mqttClient;
	/** The MQTT retained flag */
	private final boolean retained;
	/** The MQTT QOS */
	private final int qos;



	/**
	 * @param topic MQTT Topic
	 * @param mqttClient MQTT Client
	 * @param qos MQTT QOS
	 * @param retained MQTT retained flag
	 */
	public MqttPacketOutputStream(String topic, IMqttAsyncClient mqttClient, int qos, boolean retained) {
		super();
		this.topic = topic;
		this.mqttClient = mqttClient;
		this.qos = qos;
		this.retained = retained;
	}



	@Override
	public void flush() throws IOException {
		super.flush();
		byte[] data = this.toByteArray();
		try {
			mqttClient.publish(topic, data, qos, retained);
		} catch (MqttException e) {
			throw new IOException(e);
		}
	}

}
