/*
 * Java
 *
 * Copyright 2016 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package ej.giml.annotation;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import javax.annotation.processing.SupportedSourceVersion;
import javax.lang.model.SourceVersion;

/**
 * An annotation to tag methods that add child to the enclosing GIML element. Tagged element becomes a container. First
 * argument of this method should be a GIML element, other arguments will become attributes of this container.
 */
@SupportedSourceVersion(SourceVersion.RELEASE_7)
@Target(ElementType.METHOD)
@Retention(RetentionPolicy.SOURCE)
public @interface ElementChild {
	/**
	 * The GIML container name. Empty name means to use the method name (minus its prefix) ad container name.
	 *
	 * @return the name of this container.
	 */
	String name() default "";

	/**
	 * Prefix of the method. This prefix is removed from method name to compute this container name. Empty prefix means
	 * to look for default prefix in methods names ({@code add} and {@code set}).
	 *
	 * @return the prefix of this container.
	 */
	String prefix() default "";

	/**
	 * Gives the cardinality of this container (i.e. the number of times this container can appears in the enclosing
	 * GIML element.
	 *
	 * @return the cardinality of this container.
	 */
	int cardinality() default 1;

	/**
	 * Gets if this list of this container are ordered, i.e. if container declaration order must be preserved.
	 *
	 * @return {@code true} if order must be preserved, {@code false} otherwise.
	 */
	boolean ordered() default false;

	/**
	 * Gets if this child is disabled for this element. Useful to override element's parent behavior.
	 * 
	 * @return @return {@code true} if child is disabled, {@code false} otherwise.
	 */
	boolean disabled() default false;
}
