/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.widget.basic.picto;

import ej.microui.display.Font;
import ej.microui.display.GraphicsContext;
import ej.style.Style;
import ej.style.container.Rectangle;
import ej.style.util.StyleHelper;
import ej.widget.basic.AbstractSlider;
import ej.widget.model.BoundedRangeModel;
import ej.widget.model.DefaultBoundedRangeModel;

/**
 * A slider using some pictos to render.
 */
public class PictoSlider extends AbstractSlider {

	/**
	 * Creates a horizontal slider with the given model.
	 *
	 * @param model
	 *            the model to use.
	 */
	public PictoSlider(BoundedRangeModel model) {
		super(model);
	}

	/**
	 * Creates a horizontal slider with a default bounded range model.
	 *
	 * @param min
	 *            the minimum value of the slider.
	 * @param max
	 *            the maximum value of the slider.
	 * @param initialValue
	 *            the initial value of the slider.
	 * @see DefaultBoundedRangeModel
	 */
	public PictoSlider(int min, int max, int initialValue) {
		super(min, max, initialValue);
	}

	@Override
	protected float computePercentComplete(int pointerX, int pointerY) {
		Rectangle contentBounds = getContentBounds();
		Font font = StyleHelper.getFont(getStyle());
		int barWidth = font.charWidth(getBar());
		return (float) (getRelativeX(pointerX) - contentBounds.getX() - ((contentBounds.getWidth() - barWidth) >> 1))
				/ barWidth;
	}

	@Override
	public void renderContent(GraphicsContext g, Style style, Rectangle bounds) {
		int width = bounds.getWidth();
		int height = bounds.getHeight();

		Font font = StyleHelper.getFont(style);

		char bar = getBar();
		int barWidth = font.charWidth(bar);
		int xBarStart = (width - barWidth) >> 1;
		int xCursor = xBarStart + (int) (barWidth * getPercentComplete());
		int yCursor = height >> 1;

		g.setFont(font);

		int foregroundColor = style.getForegroundColor();
		g.setColor(foregroundColor);

		// Draw the bar.
		g.drawChar(bar, width >> 1, height >> 1, GraphicsContext.HCENTER | GraphicsContext.VCENTER);

		// Draw the cursor.
		g.drawChar(getCursor(), xCursor, yCursor, GraphicsContext.HCENTER | GraphicsContext.VCENTER);
	}

	private char getBar() {
		return Pictos.SLIDER_BAR;
	}

	private char getCursor() {
		return Pictos.SLIDER_CURSOR;
	}

	@Override
	public Rectangle validateContent(Style style, Rectangle availableSize) {
		Font font = StyleHelper.getFont(style);
		int width = font.charWidth(getBar()) + font.charWidth(getCursor());
		int height = font.getHeight();
		return new Rectangle(0, 0, width, height);
	}

}
